## Environment Variables

| Name | Type | Default Value | Description |
|------|------|---------------|-------------|
| APP_PROVIDER_SERVICE_NAME | string | app-provider | The name of the service. This needs to be changed when using more than one app provider. Each app provider configured needs to be identified by a unique service name. Possible examples are: 'app-provider-collabora', 'app-provider-onlyoffice', 'app-provider-office365'.|
| OCIS_TRACING_ENABLED<br/>APP_PROVIDER_TRACING_ENABLED | bool | false | Activates tracing.|
| OCIS_TRACING_TYPE<br/>APP_PROVIDER_TRACING_TYPE | string |  | The type of tracing. Defaults to '', which is the same as 'jaeger'. Allowed tracing types are 'jaeger' and '' as of now.|
| OCIS_TRACING_ENDPOINT<br/>APP_PROVIDER_TRACING_ENDPOINT | string |  | The endpoint of the tracing agent.|
| OCIS_TRACING_COLLECTOR<br/>APP_PROVIDER_TRACING_COLLECTOR | string |  | The HTTP endpoint for sending spans directly to a collector, i.e. http://jaeger-collector:14268/api/traces. Only used if the tracing endpoint is unset.|
| OCIS_LOG_LEVEL<br/>APP_PROVIDER_LOG_LEVEL | string |  | The log level. Valid values are: 'panic', 'fatal', 'error', 'warn', 'info', 'debug', 'trace'.|
| OCIS_LOG_PRETTY<br/>APP_PROVIDER_LOG_PRETTY | bool | false | Activates pretty log output.|
| OCIS_LOG_COLOR<br/>APP_PROVIDER_LOG_COLOR | bool | false | Activates colorized log output.|
| OCIS_LOG_FILE<br/>APP_PROVIDER_LOG_FILE | string |  | The path to the log file. Activates logging to this file if set.|
| APP_PROVIDER_DEBUG_ADDR | string | 127.0.0.1:9165 | Bind address of the debug server, where metrics, health, config and debug endpoints will be exposed.|
| APP_PROVIDER_DEBUG_TOKEN | string |  | Token to secure the metrics endpoint|
| APP_PROVIDER_DEBUG_PPROF | bool | false | Enables pprof, which can be used for profiling|
| APP_PROVIDER_DEBUG_ZPAGES | bool | false | Enables zpages, which can  be used for collecting and viewing traces in-memory.|
| APP_PROVIDER_GRPC_ADDR | string | 127.0.0.1:9164 | The bind address of the GRPC service.|
| OCIS_GRPC_PROTOCOL<br/>APP_PROVIDER_GRPC_PROTOCOL | string | tcp | The transport protocol of the GPRC service.|
| OCIS_JWT_SECRET<br/>APP_PROVIDER_JWT_SECRET | string |  | The secret to mint and validate jwt tokens.|
| OCIS_REVA_GATEWAY | string | com.owncloud.api.gateway | The CS3 gateway endpoint.|
| OCIS_GRPC_CLIENT_TLS_MODE | string |  | TLS mode for grpc connection to the go-micro based grpc services. Possible values are 'off', 'insecure' and 'on'. 'off': disables transport security for the clients. 'insecure' allows using transport security, but disables certificate verification (to be used with the autogenerated self-signed certificates). 'on' enables transport security, including server certificate verification.|
| OCIS_GRPC_CLIENT_TLS_CACERT | string |  | Path/File name for the root CA certificate (in PEM format) used to validate TLS server certificates of the go-micro based grpc services.|
| APP_PROVIDER_EXTERNAL_ADDR | string | com.owncloud.api.app-provider | Address of the app provider, where the GATEWAY service can reach it.|
| APP_PROVIDER_DRIVER | string |  | Driver, the APP PROVIDER services uses. Only 'wopi' is supported as of now.|
| APP_PROVIDER_WOPI_APP_API_KEY | string |  | API key for the wopi app.|
| APP_PROVIDER_WOPI_APP_DESKTOP_ONLY | bool | false | Offer this app only on desktop.|
| APP_PROVIDER_WOPI_APP_ICON_URI | string |  | URI to an app icon to be used by clients.|
| APP_PROVIDER_WOPI_APP_INTERNAL_URL | string |  | Internal URL to the app, like in your DMZ.|
| APP_PROVIDER_WOPI_APP_NAME | string |  | Human readable app name.|
| APP_PROVIDER_WOPI_APP_URL | string |  | URL for end users to access the app.|
| APP_PROVIDER_WOPI_DISABLE_CHAT<br/>OCIS_WOPI_DISABLE_CHAT | bool | false | Disable the chat functionality of the office app.|
| APP_PROVIDER_WOPI_INSECURE | bool | false | Disable TLS certificate validation for requests to the WOPI server and the web office application. Do not set this in production environments.|
| APP_PROVIDER_WOPI_WOPI_SERVER_IOP_SECRET | string |  | Shared secret of the CS3org WOPI server.|
| APP_PROVIDER_WOPI_WOPI_SERVER_EXTERNAL_URL | string |  | External url of the CS3org WOPI server.|
| OCIS_URL<br/>APP_PROVIDER_WOPI_FOLDER_URL_BASE_URL | string | https://localhost:9200/ | Base url to navigate back from the app to the containing folder in the file list.|
| APP_PROVIDER_WOPI_FOLDER_URL_PATH_TEMPLATE | string | /f/{{.ResourceID}} | Path template to navigate back from the app to the containing folder in the file list. Supported template variables are {{.ResourceInfo.ResourceID}}, {{.ResourceInfo.Mtime.Seconds}}, {{.ResourceInfo.Name}}, {{.ResourceInfo.Path}}, {{.ResourceInfo.Type}}, {{.ResourceInfo.Id.SpaceId}}, {{.ResourceInfo.Id.StorageId}}, {{.ResourceInfo.Id.OpaqueId}}, {{.ResourceInfo.MimeType}}|