## Environment Variables

| Name | Type | Default Value | Description |
|------|------|---------------|-------------|
| OCIS_TRACING_ENABLED<br/>GATEWAY_TRACING_ENABLED | bool | false | Activates tracing.|
| OCIS_TRACING_TYPE<br/>GATEWAY_TRACING_TYPE | string |  | The type of tracing. Defaults to '', which is the same as 'jaeger'. Allowed tracing types are 'jaeger' and '' as of now.|
| OCIS_TRACING_ENDPOINT<br/>GATEWAY_TRACING_ENDPOINT | string |  | The endpoint of the tracing agent.|
| OCIS_TRACING_COLLECTOR<br/>GATEWAY_TRACING_COLLECTOR | string |  | The HTTP endpoint for sending spans directly to a collector, i.e. http://jaeger-collector:14268/api/traces. Only used if the tracing endpoint is unset.|
| OCIS_LOG_LEVEL<br/>GATEWAY_LOG_LEVEL | string |  | The log level. Valid values are: 'panic', 'fatal', 'error', 'warn', 'info', 'debug', 'trace'.|
| OCIS_LOG_PRETTY<br/>GATEWAY_LOG_PRETTY | bool | false | Activates pretty log output.|
| OCIS_LOG_COLOR<br/>GATEWAY_LOG_COLOR | bool | false | Activates colorized log output.|
| OCIS_LOG_FILE<br/>GATEWAY_LOG_FILE | string |  | The path to the log file. Activates logging to this file if set.|
| GATEWAY_DEBUG_ADDR | string | 127.0.0.1:9143 | Bind address of the debug server, where metrics, health, config and debug endpoints will be exposed.|
| GATEWAY_DEBUG_TOKEN | string |  | Token to secure the metrics endpoint.|
| GATEWAY_DEBUG_PPROF | bool | false | Enables pprof, which can be used for profiling.|
| GATEWAY_DEBUG_ZPAGES | bool | false | Enables zpages, which can be used for collecting and viewing in-memory traces.|
| OCIS_GATEWAY_GRPC_ADDR<br/>GATEWAY_GRPC_ADDR | string | 127.0.0.1:9142 | The bind address of the GRPC service.|
| OCIS_GRPC_PROTOCOL<br/>GATEWAY_GRPC_PROTOCOL | string | tcp | The transport protocol of the GRPC service.|
| OCIS_JWT_SECRET<br/>GATEWAY_JWT_SECRET | string |  | The secret to mint and validate jwt tokens.|
| OCIS_REVA_GATEWAY | string | com.owncloud.api.gateway | The CS3 gateway endpoint.|
| OCIS_GRPC_CLIENT_TLS_MODE | string |  | TLS mode for grpc connection to the go-micro based grpc services. Possible values are 'off', 'insecure' and 'on'. 'off': disables transport security for the clients. 'insecure' allows using transport security, but disables certificate verification (to be used with the autogenerated self-signed certificates). 'on' enables transport security, including server certificate verification.|
| OCIS_GRPC_CLIENT_TLS_CACERT | string |  | Path/File name for the root CA certificate (in PEM format) used to validate TLS server certificates of the go-micro based grpc services.|
| GATEWAY_SKIP_USER_GROUPS_IN_TOKEN | bool | false | Disables the loading of user's group memberships from the reva access token.|
| GATEWAY_COMMIT_SHARE_TO_STORAGE_GRANT | bool | true | Commit shares to storage grants. This grants access to shared resources for the share receiver directly on the storage.|
| GATEWAY_SHARE_FOLDER_NAME | string | Shares | Name of the share folder in users' home space.|
| GATEWAY_DISABLE_HOME_CREATION_ON_LOGIN | bool | true | Disable creation of the home space on login.|
| OCIS_TRANSFER_SECRET | string |  | The storage transfer secret.|
| GATEWAY_TRANSFER_EXPIRES | int | 86400 | Expiry for the gateway tokens.|
| OCIS_CACHE_STORE<br/>GATEWAY_PROVIDER_CACHE_STORE | string | noop | The type of the cache store. Supported values are: 'memory', 'redis-sentinel', 'nats-js-kv', 'noop'. See the text description for details.|
| OCIS_CACHE_STORE_NODES<br/>GATEWAY_PROVIDER_CACHE_STORE_NODES | []string | [127.0.0.1:9233] | A list of nodes to access the configured store. This has no effect when 'memory' store is configured. Note that the behaviour how nodes are used is dependent on the library of the configured store. See the Environment Variable Types description for more details.|
| OCIS_CACHE_DATABASE | string | cache-providers | The database name the configured store should use.|
| OCIS_CACHE_TTL<br/>GATEWAY_PROVIDER_CACHE_TTL | Duration | 5m0s | Default time to live for user info in the cache. Only applied when access tokens has no expiration. See the Environment Variable Types description for more details.|
| OCIS_CACHE_DISABLE_PERSISTENCE<br/>GATEWAY_PROVIDER_CACHE_DISABLE_PERSISTENCE | bool | false | Disables persistence of the provider cache. Only applies when store type 'nats-js-kv' is configured. Defaults to false.|
| OCIS_CACHE_AUTH_USERNAME<br/>GATEWAY_PROVIDER_CACHE_AUTH_USERNAME | string |  | The username to use for authentication. Only applies when store type 'nats-js-kv' is configured.|
| OCIS_CACHE_AUTH_PASSWORD<br/>GATEWAY_PROVIDER_CACHE_AUTH_PASSWORD | string |  | The password to use for authentication. Only applies when store type 'nats-js-kv' is configured.|
| OCIS_CACHE_STORE<br/>GATEWAY_CREATE_HOME_CACHE_STORE | string | memory | The type of the cache store. Supported values are: 'memory', 'redis-sentinel', 'nats-js-kv', 'noop'. See the text description for details.|
| OCIS_CACHE_STORE_NODES<br/>GATEWAY_CREATE_HOME_CACHE_STORE_NODES | []string | [127.0.0.1:9233] | A list of nodes to access the configured store. This has no effect when 'memory' store is configured. Note that the behaviour how nodes are used is dependent on the library of the configured store. See the Environment Variable Types description for more details.|
| OCIS_CACHE_DATABASE | string | cache-createhome | The database name the configured store should use.|
| OCIS_CACHE_TTL<br/>GATEWAY_CREATE_HOME_CACHE_TTL | Duration | 5m0s | Default time to live for user info in the cache. Only applied when access tokens has no expiration. See the Environment Variable Types description for more details.|
| OCIS_CACHE_DISABLE_PERSISTENCE<br/>GATEWAY_CREATE_HOME_CACHE_DISABLE_PERSISTENCE | bool | false | Disables persistence of the create home cache. Only applies when store type 'nats-js-kv' is configured. Defaults to false.|
| OCIS_CACHE_AUTH_USERNAME<br/>GATEWAY_CREATE_HOME_CACHE_AUTH_USERNAME | string |  | The username to use for authentication. Only applies when store type 'nats-js-kv' is configured.|
| OCIS_CACHE_AUTH_PASSWORD<br/>GATEWAY_CREATE_HOME_CACHE_AUTH_PASSWORD | string |  | The password to use for authentication. Only applies when store type 'nats-js-kv' is configured.|
| OCIS_URL<br/>GATEWAY_FRONTEND_PUBLIC_URL | string | https://localhost:9200 | The public facing URL of the oCIS frontend.|
| GATEWAY_USERS_ENDPOINT | string | com.owncloud.api.users | The endpoint of the users service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_GROUPS_ENDPOINT | string | com.owncloud.api.groups | The endpoint of the groups service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_PERMISSIONS_ENDPOINT | string | com.owncloud.api.settings | The endpoint of the permissions service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_SHARING_ENDPOINT | string | com.owncloud.api.sharing | The endpoint of the shares service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_AUTH_APP_ENDPOINT | string | com.owncloud.api.auth-app | The endpoint of the auth-app service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_AUTH_BASIC_ENDPOINT | string | com.owncloud.api.auth-basic | The endpoint of the auth-basic service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_AUTH_BEARER_ENDPOINT | string |  | The endpoint of the auth-bearer service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_AUTH_MACHINE_ENDPOINT | string | com.owncloud.api.auth-machine | The endpoint of the auth-machine service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_AUTH_SERVICE_ENDPOINT | string | com.owncloud.api.auth-service | The endpoint of the auth-service service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_STORAGE_PUBLIC_LINK_ENDPOINT | string | com.owncloud.api.storage-publiclink | The endpoint of the storage-publiclink service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_STORAGE_USERS_ENDPOINT | string | com.owncloud.api.storage-users | The endpoint of the storage-users service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_STORAGE_SHARES_ENDPOINT | string | com.owncloud.api.storage-shares | The endpoint of the storage-shares service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_APP_REGISTRY_ENDPOINT | string | com.owncloud.api.app-registry | The endpoint of the app-registry service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_OCM_ENDPOINT | string | com.owncloud.api.ocm | The endpoint of the ocm service. Can take a service name or a gRPC URI with the dns, kubernetes or unix protocol.|
| GATEWAY_STORAGE_REGISTRY_DRIVER | string | spaces | The driver name of the storage registry to use.|
| GATEWAY_STORAGE_REGISTRY_RULES | []string | [] | The rules for the storage registry. See the Environment Variable Types description for more details.|
| GATEWAY_STORAGE_REGISTRY_CONFIG_JSON | string |  | Additional configuration for the storage registry in json format.|
| GATEWAY_STORAGE_USERS_MOUNT_ID | string |  | Mount ID of this storage. Admins can set the ID for the storage in this config option manually which is then used to reference the storage. Any reasonable long string is possible, preferably this would be an UUIDv4 format.|